@@ -3,7 +3,7 @@ import sys
 from parsec import one, eof
 from parsec.combinator import *
 from parsec.text import *
-from .market_math import processor
+from .marked_math import processor
 
 """
 使用 markdown 编写的问题应该总是一个固定格式，即
@@ -185,7 +185,7 @@ def paragraph(state):
             continue
         finally:
             state.rollback(tran)
-        return Paragraph(processor(buffer), "markdown")
+        return Paragraph(processor(buffer).strip(), "markdown")
 
     return Paragraph(processor(buffer), "markdown")
 
